@@ -19,7 +19,6 @@ check_css_param <- function(CSS) {
 # the content of a data frame into a HTML table that is returned.
 
 #' @importFrom sjmisc is_empty var_type is_even trim
-#' @importFrom tibble has_rownames has_name rownames_to_column
 tab_df_content <- function(
   mydf,
   title,
@@ -76,8 +75,8 @@ tab_df_content <- function(
   # check if rownames should be shown and data has any rownames at all
   # if so, we need to update our information on column names
 
-  if (show.rownames && tibble::has_rownames(mydf)) {
-    mydf <- tibble::rownames_to_column(mydf)
+  if (show.rownames && obj_has_rownames(mydf)) {
+    mydf <- rownames_as_column(mydf)
     colcnt <- colcnt + 1
     cnames <- c("Row", cnames)
   }
@@ -401,38 +400,39 @@ tab_df_prepare_style <- function(CSS = NULL, content = NULL, task, ...) {
     content <- gsub("<caption", sprintf("<caption style=\"%s\"", css.caption), content, fixed = TRUE, useBytes = TRUE)
 
     # replace class-attributes with inline-style-definitions
-    content <- gsub(tag.tdata, css.tdata, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.thead, css.thead, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.arc, css.arc, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.footnote, css.footnote, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.subtitle, css.subtitle, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.lasttablerow, css.lasttablerow, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.firsttablerow, css.firsttablerow, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.firsttablecol, css.firsttablecol, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.leftalign, css.leftalign, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.centeralign, css.centeralign, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.summarydata, css.summarydata, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.summary, css.summary, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.fixedparts, css.fixedparts, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.randomparts, css.randomparts, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.zeroparts, css.zeroparts, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.firstsumrow, css.firstsumrow, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.depvarhead, css.depvarhead, content, fixed = TRUE, useBytes = TRUE)
+    # gsub("\"(.*)(summary)(.*)\"", "\\1haha\\3", "test \"abc summary def\"")
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.tdata), sprintf("\"\\1%s\\3\"", css.tdata), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.thead), sprintf("\"\\1%s\\3\"", css.thead), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.arc), sprintf("\"\\1%s\\3\"", css.arc), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.footnote), sprintf("\"\\1%s\\3\"", css.footnote), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.subtitle), sprintf("\"\\1%s\\3\"", css.subtitle), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.lasttablerow), sprintf("\"\\1%s\\3\"", css.lasttablerow), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.firsttablerow), sprintf("\"\\1%s\\3\"", css.firsttablerow), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.firsttablecol), sprintf("\"\\1%s\\3\"", css.firsttablecol), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.leftalign), sprintf("\"\\1%s\\3\"", css.leftalign), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.centeralign), sprintf("\"\\1%s\\3\"", css.centeralign), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.summarydata), sprintf("\"\\1%s\\3\"", css.summarydata), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.summary), sprintf("\"\\1%s\\3\"", css.summary), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.fixedparts), sprintf("\"\\1%s\\3\"", css.fixedparts), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.randomparts), sprintf("\"\\1%s\\3\"", css.randomparts), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.zeroparts), sprintf("\"\\1%s\\3\"", css.zeroparts), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.firstsumrow), sprintf("\"\\1%s\\3\"", css.firstsumrow), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.depvarhead), sprintf("\"\\1%s\\3\"", css.depvarhead), content, perl = TRUE)
 
-    content <- gsub(tag.col1, css.col1, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.col2, css.col2, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.col3, css.col3, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.col4, css.col4, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.col5, css.col5, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.col6, css.col6, content, fixed = TRUE, useBytes = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.col1), sprintf("\"\\1%s\\3\"", css.col1), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.col2), sprintf("\"\\1%s\\3\"", css.col2), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.col3), sprintf("\"\\1%s\\3\"", css.col3), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.col4), sprintf("\"\\1%s\\3\"", css.col4), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.col5), sprintf("\"\\1%s\\3\"", css.col5), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.col6), sprintf("\"\\1%s\\3\"", css.col6), content, perl = TRUE)
 
-    content <- gsub(tag.modelcolumn1, css.modelcolumn1, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.modelcolumn2, css.modelcolumn2, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.modelcolumn3, css.modelcolumn3, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.modelcolumn4, css.modelcolumn4, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.modelcolumn5, css.modelcolumn5, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.modelcolumn6, css.modelcolumn6, content, fixed = TRUE, useBytes = TRUE)
-    content <- gsub(tag.modelcolumn7, css.modelcolumn7, content, fixed = TRUE, useBytes = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.modelcolumn1), sprintf("\"\\1%s\\3\"", css.modelcolumn1), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.modelcolumn2), sprintf("\"\\1%s\\3\"", css.modelcolumn2), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.modelcolumn3), sprintf("\"\\1%s\\3\"", css.modelcolumn3), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.modelcolumn4), sprintf("\"\\1%s\\3\"", css.modelcolumn4), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.modelcolumn5), sprintf("\"\\1%s\\3\"", css.modelcolumn5), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.modelcolumn6), sprintf("\"\\1%s\\3\"", css.modelcolumn6), content, perl = TRUE)
+    content <- gsub(sprintf("\"(.*)(%s)(.*)\"", tag.modelcolumn7), sprintf("\"\\1%s\\3\"", css.modelcolumn7), content, perl = TRUE)
 
     content <- gsub("<td style=\"", sprintf("<td style=\"%s ", css.td), content, fixed = TRUE, useBytes = TRUE)
   }
